Välkommen till Försäkringskassan - Försäkringskassan
Description: Välkommen till Försäkringskassan. Här får du veta vilka bidrag och ersättningar du har rätt till och hur du ansöker om dem. Du kan sköta de flesta av dina ärenden själv med hjälp av våra e-tjänster.
Keywords: Försäkringskassan

# Privatperson

### Direktlänkar

- till innehållet
- till huvudmenyn
- till detaljmenyn
- till hjälpfunktioner

Cookies
Försäkringskassan använder cookies för att förbättra och anpassa ditt besök på vår webbplats. Genom att klicka på "Jag accepterar-knappen" samtycker du till att cookies används. För att kunna använda Mina sidor och en del andra funktioner behöver du acceptera cookies. Läs mer om cookies
Jag accepterar
{}

## Webbinnehållsvisning (JSR 286)

ï¿½tgï¿½rder

- ${title}

Lï¿½ser in...

# Välkommen till Försäkringskassan

### Förälder

Anmäl föräldrapenning Anmäl och ansök om VAB Tjänster för dig som väntar barn

### Sjuk

Anställd Arbetssökande Föräldraledig Har aktiebolag Har enskild firma Studerande

### Arbetssökande

Om du är arbetssökande Om du riskerar att bli arbetssökande

### Funktionsnedsättning

Assistansersättning Bilstöd Handikappersättning

### Nyheter

5 december
  Nya regler om ersättning för höga sjuklönekostnader 1 januari 2015
5 december
  Reglerna för att ansöka om föräldrapenning i efterhand kommer att ändras 1 januari 2015
5 december
  Underhållsstödet kommer inte att höjas efter årsskiftet
5 december
  Aktivitetsstödet kommer inte att höjas efter årsskiftet
4 december
  Antalet sjukskrivna fortsätter att öka
1 december
  Delade utbetalningar från Försäkringskassan och Pensionsmyndigheten efter årsskiftet

Se alla nyheter

### Aktuellt

- Beställ EU-kort inför utlandsresan
- Du som har ett barn som fyller 16 år i år
- Falska undersökningar kommer upp på forsakringskassan.se
- När kommer pengarna den här månaden? Se utbetalningsdagar.

Complementary Content